==> kubernetes-model-1.0.64-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/HorizontalPodAutoscalerSpecFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.sundr.builder.annotations.Buildable;
import javax.annotation.Generated;
import io.fabric8.kubernetes.api.builder.Fluent;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Integer;
import javax.validation.Valid;
import java.lang.Object;
import lombok.ToString;
import java.util.Map;

public interface HorizontalPodAutoscalerSpecFluent<A extends HorizontalPodAutoscalerSpecFluent<A>> extends Fluent<A>{


    public CPUTargetUtilization getCpuUtilization();
    public A withCpuUtilization(CPUTargetUtilization cpuUtilization);
    public HorizontalPodAutoscalerSpecFluent.CpuUtilizationNested<A> withNewCpuUtilization();
    public HorizontalPodAutoscalerSpecFluent.CpuUtilizationNested<A> withNewCpuUtilizationLike(CPUTargetUtilization item);
    public HorizontalPodAutoscalerSpecFluent.CpuUtilizationNested<A> editCpuUtilization();
    public HorizontalPodAutoscalerSpecFluent.CpuUtilizationNested<A> editOrNewCpuUtilization();
    public HorizontalPodAutoscalerSpecFluent.CpuUtilizationNested<A> editOrNewCpuUtilizationLike(CPUTargetUtilization item);
    public A withNewCpuUtilization(Integer targetPercentage);
    public Integer getMaxReplicas();
    public A withMaxReplicas(Integer maxReplicas);
    public Integer getMinReplicas();
    public A withMinReplicas(Integer minReplicas);
    public SubresourceReference getScaleRef();
    public A withScaleRef(SubresourceReference scaleRef);
    public HorizontalPodAutoscalerSpecFluent.ScaleRefNested<A> withNewScaleRef();
    public HorizontalPodAutoscalerSpecFluent.ScaleRefNested<A> withNewScaleRefLike(SubresourceReference item);
    public HorizontalPodAutoscalerSpecFluent.ScaleRefNested<A> editScaleRef();
    public HorizontalPodAutoscalerSpecFluent.ScaleRefNested<A> editOrNewScaleRef();
    public HorizontalPodAutoscalerSpecFluent.ScaleRefNested<A> editOrNewScaleRefLike(SubresourceReference item);
    public A withNewScaleRef(String apiVersion,String kind,String name,String subresource);

    public interface CpuUtilizationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CPUTargetUtilizationFluent<HorizontalPodAutoscalerSpecFluent.CpuUtilizationNested<N>>{

        
    public N and();    public N endCpuUtilization();
}
    public interface ScaleRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SubresourceReferenceFluent<HorizontalPodAutoscalerSpecFluent.ScaleRefNested<N>>{

        
    public N and();    public N endScaleRef();
}


}

==> kubernetes-model-1.0.65-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/HorizontalPodAutoscalerSpecFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface HorizontalPodAutoscalerSpecFluent<A extends HorizontalPodAutoscalerSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildCpuUtilization instead.
 */
@Deprecated public CPUTargetUtilization getCpuUtilization();
    public CPUTargetUtilization buildCpuUtilization();
    public A withCpuUtilization(CPUTargetUtilization cpuUtilization);
    public Boolean hasCpuUtilization();
    public HorizontalPodAutoscalerSpecFluent.CpuUtilizationNested<A> withNewCpuUtilization();
    public HorizontalPodAutoscalerSpecFluent.CpuUtilizationNested<A> withNewCpuUtilizationLike(CPUTargetUtilization item);
    public HorizontalPodAutoscalerSpecFluent.CpuUtilizationNested<A> editCpuUtilization();
    public HorizontalPodAutoscalerSpecFluent.CpuUtilizationNested<A> editOrNewCpuUtilization();
    public HorizontalPodAutoscalerSpecFluent.CpuUtilizationNested<A> editOrNewCpuUtilizationLike(CPUTargetUtilization item);
    public A withNewCpuUtilization(Integer targetPercentage);
    public Integer getMaxReplicas();
    public A withMaxReplicas(Integer maxReplicas);
    public Boolean hasMaxReplicas();
    public Integer getMinReplicas();
    public A withMinReplicas(Integer minReplicas);
    public Boolean hasMinReplicas();
    
/**
 * This method has been deprecated, please use method buildScaleRef instead.
 */
@Deprecated public SubresourceReference getScaleRef();
    public SubresourceReference buildScaleRef();
    public A withScaleRef(SubresourceReference scaleRef);
    public Boolean hasScaleRef();
    public HorizontalPodAutoscalerSpecFluent.ScaleRefNested<A> withNewScaleRef();
    public HorizontalPodAutoscalerSpecFluent.ScaleRefNested<A> withNewScaleRefLike(SubresourceReference item);
    public HorizontalPodAutoscalerSpecFluent.ScaleRefNested<A> editScaleRef();
    public HorizontalPodAutoscalerSpecFluent.ScaleRefNested<A> editOrNewScaleRef();
    public HorizontalPodAutoscalerSpecFluent.ScaleRefNested<A> editOrNewScaleRefLike(SubresourceReference item);
    public A withNewScaleRef(String apiVersion,String kind,String name,String subresource);

    public interface CpuUtilizationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CPUTargetUtilizationFluent<HorizontalPodAutoscalerSpecFluent.CpuUtilizationNested<N>>{

        
    public N and();    public N endCpuUtilization();
}
    public interface ScaleRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SubresourceReferenceFluent<HorizontalPodAutoscalerSpecFluent.ScaleRefNested<N>>{

        
    public N and();    public N endScaleRef();
}


}
